@@ -1,4 +1,5 @@
-from typing import Any
+from typing import Generic
+from typing import TypeVar
 
 from pydantic import BaseModel
 from pydantic import Field
@@ -6,11 +7,28 @@ from pydantic import validator
 
 from frinx.common.conductor_enums import TaskResultStatus
 from frinx.common.util import snake_to_camel_case
+from frinx.common.worker.task_def import TaskOutput
+
+T = TypeVar('T')
 
 
-class TaskResult(BaseModel):
+class Registry(Generic[T]):
+    def __init__(self) -> None:
+        self._store: dict[str, T] = {}
+
+    def set_item(self, k: str, v: T) -> None:
+        self._store[k] = v
+
+    def get_item(self, k: str) -> T:
+        return self._store[k]
+
+
+TO = TypeVar('TO', bound=TaskOutput | None)
+
+
+class TaskResult(BaseModel, Generic[TO]):
     status: TaskResultStatus
-    output: dict[str, Any] = Field(default={})
+    output: TO | None = None
     logs: list[str] | str = Field(default=[])
 
     class Config:
@@ -25,11 +43,3 @@ class TaskResult(BaseModel):
                 return logs
             case str():
                 return [logs]
-
-    def add_output_data(self, key: str, value: Any) -> None:
-        if self.output is None:
-            self.output = {}
-        self.output[key] = value
-
-    def add_output_data_dict(self, data: dict[str, Any]) -> None:
-        self.output = data
